package brj.entities.embed;

import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.EntityTransaction;
import javax.persistence.Persistence;

import org.hibernate.envers.AuditReader;
import org.hibernate.envers.AuditReaderFactory;
import org.junit.Assert;
import org.junit.Test;

public class JunitTests {

    @Test
    public void test() {
        EntityManagerFactory emf = Persistence.createEntityManagerFactory("TEST");
        EntityManager em = emf.createEntityManager();
    
        SimplePerson person = new SimplePerson();
        person.setName("Person 1");
        person.setTestCode(new TestCode(84));
        person.setGenericCode(new Code(42, "TestCodeart"));
      
        EntityTransaction tx = em.getTransaction();
        tx.begin();
        em.persist(person);
        tx.commit();
        em.close();
    
        // Reload and Compare Revision
        em = emf.createEntityManager();    
        SimplePerson personLoaded = em.find(SimplePerson.class, person.getId());
        
        AuditReader reader = AuditReaderFactory.get(em);

        List<Number> revs = reader.getRevisions(SimplePerson.class, person.getId());
        Assert.assertEquals(1, revs.size());

        SimplePerson personRev1 = reader.find(SimplePerson.class, person.getId(), revs.get(0));

        Assert.assertEquals(personLoaded.getName(), personRev1.getName());

        // Generic Code is read from AUD Table
        Assert.assertEquals(personLoaded.getGenericCode(), personRev1.getGenericCode());
        
        // Test Code is NOT read from AUD Table
        Assert.assertEquals(personLoaded.getTestCode(), personRev1.getTestCode());
    }

}
